# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/integrations/v1/api.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/integrations/v1/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from spounge.nodus.v1.common.v1 import auth_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"nodus/v1/integrations/v1/api.proto\x12\x18nodus.v1.integrations.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dnodus/v1/common/v1/auth.proto\"\x8e\x04\n\tAPIConfig\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x19\n\x08\x62\x61se_url\x18\x02 \x01(\tR\x07\x62\x61seUrl\x12I\n\x0b\x61uth_config\x18\x04 \x01(\x0b\x32(.nodus.v1.common.v1.AuthenticationConfigR\nauthConfig\x12`\n\x0f\x64\x65\x66\x61ult_headers\x18\x05 \x03(\x0b\x32\x37.nodus.v1.integrations.v1.APIConfig.DefaultHeadersEntryR\x0e\x64\x65\x66\x61ultHeaders\x12\x33\n\x07timeout\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x12O\n\x0cretry_config\x18\x07 \x01(\x0b\x32,.nodus.v1.integrations.v1.RetryConfigurationR\x0bretryConfig\x12\\\n\x11rate_limit_config\x18\x08 \x01(\x0b\x32\x30.nodus.v1.integrations.v1.RateLimitConfigurationR\x0frateLimitConfig\x1a\x41\n\x13\x44\x65\x66\x61ultHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x9c\x02\n\x12RetryConfiguration\x12!\n\x0cmax_attempts\x18\x01 \x01(\x05R\x0bmaxAttempts\x12\x42\n\x0finitial_backoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0einitialBackoff\x12:\n\x0bmax_backoff\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\nmaxBackoff\x12-\n\x12\x62\x61\x63koff_multiplier\x18\x04 \x01(\x02R\x11\x62\x61\x63koffMultiplier\x12\x34\n\x16retryable_status_codes\x18\x05 \x03(\x05R\x14retryableStatusCodes\"\xa9\x01\n\x16RateLimitConfiguration\x12.\n\x13requests_per_second\x18\x01 \x01(\x05R\x11requestsPerSecond\x12.\n\x13requests_per_minute\x18\x02 \x01(\x05R\x11requestsPerMinute\x12/\n\x13\x63oncurrent_requests\x18\x03 \x01(\x05R\x12\x63oncurrentRequests\"\x8f\x03\n\x0bHTTPRequest\x12<\n\x06method\x18\x01 \x01(\x0e\x32$.nodus.v1.integrations.v1.HTTPMethodR\x06method\x12\x1a\n\x08\x65ndpoint\x18\x02 \x01(\tR\x08\x65ndpoint\x12L\n\x07headers\x18\x03 \x03(\x0b\x32\x32.nodus.v1.integrations.v1.HTTPRequest.HeadersEntryR\x07headers\x12:\n\x0cquery_params\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x0bqueryParams\x12+\n\x04\x62ody\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x62ody\x12\x33\n\x07timeout\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xa7\x02\n\x0cHTTPResponse\x12\x1f\n\x0bstatus_code\x18\x01 \x01(\x05R\nstatusCode\x12M\n\x07headers\x18\x02 \x03(\x0b\x32\x33.nodus.v1.integrations.v1.HTTPResponse.HeadersEntryR\x07headers\x12+\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x62ody\x12>\n\rresponse_time\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0cresponseTime\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xc7\x01\n\nHTTPMethod\x12\x1b\n\x17HTTP_METHOD_UNSPECIFIED\x10\x00\x12\x13\n\x0fHTTP_METHOD_GET\x10\x01\x12\x14\n\x10HTTP_METHOD_POST\x10\x02\x12\x13\n\x0fHTTP_METHOD_PUT\x10\x03\x12\x16\n\x12HTTP_METHOD_DELETE\x10\x04\x12\x15\n\x11HTTP_METHOD_PATCH\x10\x05\x12\x14\n\x10HTTP_METHOD_HEAD\x10\x06\x12\x17\n\x13HTTP_METHOD_OPTIONS\x10\x07\x42\x80\x02\n\x1c\x63om.nodus.v1.integrations.v1B\x08\x41piProtoP\x01ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\xa2\x02\x03NVI\xaa\x02\x18Nodus.V1.Integrations.V1\xca\x02\x18Nodus\\V1\\Integrations\\V1\xe2\x02$Nodus\\V1\\Integrations\\V1\\GPBMetadata\xea\x02\x1bNodus::V1::Integrations::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.integrations.v1.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.nodus.v1.integrations.v1B\010ApiProtoP\001ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\242\002\003NVI\252\002\030Nodus.V1.Integrations.V1\312\002\030Nodus\\V1\\Integrations\\V1\342\002$Nodus\\V1\\Integrations\\V1\\GPBMetadata\352\002\033Nodus::V1::Integrations::V1'
  _globals['_APICONFIG_DEFAULTHEADERSENTRY']._loaded_options = None
  _globals['_APICONFIG_DEFAULTHEADERSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPRESPONSE_HEADERSENTRY']._loaded_options = None
  _globals['_HTTPRESPONSE_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPMETHOD']._serialized_start=1846
  _globals['_HTTPMETHOD']._serialized_end=2045
  _globals['_APICONFIG']._serialized_start=158
  _globals['_APICONFIG']._serialized_end=684
  _globals['_APICONFIG_DEFAULTHEADERSENTRY']._serialized_start=619
  _globals['_APICONFIG_DEFAULTHEADERSENTRY']._serialized_end=684
  _globals['_RETRYCONFIGURATION']._serialized_start=687
  _globals['_RETRYCONFIGURATION']._serialized_end=971
  _globals['_RATELIMITCONFIGURATION']._serialized_start=974
  _globals['_RATELIMITCONFIGURATION']._serialized_end=1143
  _globals['_HTTPREQUEST']._serialized_start=1146
  _globals['_HTTPREQUEST']._serialized_end=1545
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_start=1487
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_end=1545
  _globals['_HTTPRESPONSE']._serialized_start=1548
  _globals['_HTTPRESPONSE']._serialized_end=1843
  _globals['_HTTPRESPONSE_HEADERSENTRY']._serialized_start=1487
  _globals['_HTTPRESPONSE_HEADERSENTRY']._serialized_end=1545
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/common/v1/auth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/common/v1/auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dnodus/v1/common/v1/auth.proto\x12\x12nodus.v1.common.v1\"\x89\x04\n\x14\x41uthenticationConfig\x12\x39\n\tauth_type\x18\x01 \x01(\x0e\x32\x1c.nodus.v1.common.v1.AuthTypeR\x08\x61uthType\x12\x33\n\x15\x61pi_key_credential_id\x18\x02 \x01(\tH\x00R\x12\x61piKeyCredentialId\x12=\n\x1a\x62\x65\x61rer_token_credential_id\x18\x03 \x01(\tH\x00R\x17\x62\x65\x61rerTokenCredentialId\x12\x44\n\nbasic_auth\x18\x04 \x01(\x0b\x32#.nodus.v1.common.v1.BasicAuthConfigH\x00R\tbasicAuth\x12:\n\x06oauth2\x18\x05 \x01(\x0b\x32 .nodus.v1.common.v1.OAuth2ConfigH\x00R\x06oauth2\x12l\n\x12\x63ustom_auth_params\x18\x06 \x03(\x0b\x32>.nodus.v1.common.v1.AuthenticationConfig.CustomAuthParamsEntryR\x10\x63ustomAuthParams\x1a\x43\n\x15\x43ustomAuthParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\r\n\x0b\x63redentials\"c\n\x0f\x42\x61sicAuthConfig\x12\x1a\n\x08username\x18\x01 \x01(\tR\x08username\x12\x34\n\x16password_credential_id\x18\x02 \x01(\tR\x14passwordCredentialId\"\xb9\x01\n\x0cOAuth2Config\x12\x1b\n\ttoken_url\x18\x01 \x01(\tR\x08tokenUrl\x12\x35\n\x17\x63lient_id_credential_id\x18\x02 \x01(\tR\x14\x63lientIdCredentialId\x12=\n\x1b\x63lient_secret_credential_id\x18\x03 \x01(\tR\x18\x63lientSecretCredentialId\x12\x16\n\x06scopes\x18\x04 \x03(\tR\x06scopes*\xad\x01\n\x08\x41uthType\x12\x19\n\x15\x41UTH_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41UTH_TYPE_NONE\x10\x01\x12\x15\n\x11\x41UTH_TYPE_API_KEY\x10\x02\x12\x1a\n\x16\x41UTH_TYPE_BEARER_TOKEN\x10\x03\x12\x13\n\x0f\x41UTH_TYPE_BASIC\x10\x04\x12\x14\n\x10\x41UTH_TYPE_OAUTH2\x10\x05\x12\x14\n\x10\x41UTH_TYPE_CUSTOM\x10\x06\x42\xd7\x01\n\x16\x63om.nodus.v1.common.v1B\tAuthProtoP\x01ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\xa2\x02\x03NVC\xaa\x02\x12Nodus.V1.Common.V1\xca\x02\x12Nodus\\V1\\Common\\V1\xe2\x02\x1eNodus\\V1\\Common\\V1\\GPBMetadata\xea\x02\x15Nodus::V1::Common::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.common.v1.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.nodus.v1.common.v1B\tAuthProtoP\001ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\242\002\003NVC\252\002\022Nodus.V1.Common.V1\312\002\022Nodus\\V1\\Common\\V1\342\002\036Nodus\\V1\\Common\\V1\\GPBMetadata\352\002\025Nodus::V1::Common::V1'
  _globals['_AUTHENTICATIONCONFIG_CUSTOMAUTHPARAMSENTRY']._loaded_options = None
  _globals['_AUTHENTICATIONCONFIG_CUSTOMAUTHPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_AUTHTYPE']._serialized_start=867
  _globals['_AUTHTYPE']._serialized_end=1040
  _globals['_AUTHENTICATIONCONFIG']._serialized_start=54
  _globals['_AUTHENTICATIONCONFIG']._serialized_end=575
  _globals['_AUTHENTICATIONCONFIG_CUSTOMAUTHPARAMSENTRY']._serialized_start=493
  _globals['_AUTHENTICATIONCONFIG_CUSTOMAUTHPARAMSENTRY']._serialized_end=560
  _globals['_BASICAUTHCONFIG']._serialized_start=577
  _globals['_BASICAUTHCONFIG']._serialized_end=676
  _globals['_OAUTH2CONFIG']._serialized_start=679
  _globals['_OAUTH2CONFIG']._serialized_end=864
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iam/v2/api_key.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'iam/v2/api_key.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14iam/v2/api_key.proto\x12\x06iam.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\xaa\x02\n\x06\x41PIKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x1d\n\nkey_prefix\x18\x04 \x01(\tR\tkeyPrefix\x12%\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x41\n\x0clast_used_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\nlastUsedAt\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x0f\n\r_last_used_at\"Z\n\x10\x41PIKeyWithSecret\x12\'\n\x07\x61pi_key\x18\x01 \x01(\x0b\x32\x0e.iam.v2.APIKeyR\x06\x61piKey\x12\x1d\n\nsecret_key\x18\x02 \x01(\tR\tsecretKeyB\x8c\x01\n\ncom.iam.v2B\x0b\x41piKeyProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/iam/v2;iamv2\xa2\x02\x03IXX\xaa\x02\x06Iam.V2\xca\x02\x06Iam\\V2\xe2\x02\x12Iam\\V2\\GPBMetadata\xea\x02\x07Iam::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iam.v2.api_key_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.iam.v2B\013ApiKeyProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/iam/v2;iamv2\242\002\003IXX\252\002\006Iam.V2\312\002\006Iam\\V2\342\002\022Iam\\V2\\GPBMetadata\352\002\007Iam::V2'
  _globals['_APIKEY']._serialized_start=66
  _globals['_APIKEY']._serialized_end=364
  _globals['_APIKEYWITHSECRET']._serialized_start=366
  _globals['_APIKEYWITHSECRET']._serialized_end=456
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iam/v2/managed_secret.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'iam/v2/managed_secret.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1biam/v2/managed_secret.proto\x12\x06iam.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xfc\x02\n\rManagedSecret\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12-\n\x04type\x18\x04 \x01(\x0e\x32\x19.iam.v2.ManagedSecretTypeR\x04type\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x42\n\x0f\x63ollection_data\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructH\x00R\x0e\x63ollectionData\x12\x36\n\titem_data\x18\x08 \x01(\x0b\x32\x17.google.protobuf.StructH\x00R\x08itemDataB\r\n\x0bsecret_data*\x9a\x01\n\x11ManagedSecretType\x12#\n\x1fMANAGED_SECRET_TYPE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aMANAGED_SECRET_TYPE_CUSTOM\x10\x01\x12\x1c\n\x18MANAGED_SECRET_TYPE_ITEM\x10\x02\x12\"\n\x1eMANAGED_SECRET_TYPE_COLLECTION\x10\x03\x42\x93\x01\n\ncom.iam.v2B\x12ManagedSecretProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/iam/v2;iamv2\xa2\x02\x03IXX\xaa\x02\x06Iam.V2\xca\x02\x06Iam\\V2\xe2\x02\x12Iam\\V2\\GPBMetadata\xea\x02\x07Iam::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iam.v2.managed_secret_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.iam.v2B\022ManagedSecretProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/iam/v2;iamv2\242\002\003IXX\252\002\006Iam.V2\312\002\006Iam\\V2\342\002\022Iam\\V2\\GPBMetadata\352\002\007Iam::V2'
  _globals['_MANAGEDSECRETTYPE']._serialized_start=486
  _globals['_MANAGEDSECRETTYPE']._serialized_end=640
  _globals['_MANAGEDSECRET']._serialized_start=103
  _globals['_MANAGEDSECRET']._serialized_end=483
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/integrations/v1/llm.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/integrations/v1/llm.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"nodus/v1/integrations/v1/llm.proto\x12\x18nodus.v1.integrations.v1\x1a\x1cgoogle/protobuf/struct.proto\"\xdb\x04\n\x10LLMConfiguration\x12\x41\n\x08provider\x18\x01 \x01(\x0e\x32%.nodus.v1.integrations.v1.LLMProviderR\x08provider\x12\x1d\n\nmodel_name\x18\x02 \x01(\tR\tmodelName\x12#\n\rcredential_id\x18\x03 \x01(\tR\x0c\x63redentialId\x12\x19\n\x08\x62\x61se_url\x18\x04 \x01(\tR\x07\x62\x61seUrl\x12Q\n\x07headers\x18\x06 \x03(\x0b\x32\x37.nodus.v1.integrations.v1.LLMConfiguration.HeadersEntryR\x07headers\x12J\n\x0brate_limits\x18\x07 \x01(\x0b\x32).nodus.v1.integrations.v1.RateLimitConfigR\nrateLimits\x12m\n\x11provider_specific\x18\x08 \x03(\x0b\x32@.nodus.v1.integrations.v1.LLMConfiguration.ProviderSpecificEntryR\x10providerSpecific\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a[\n\x15ProviderSpecificEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\"\xaf\x02\n\rLLMParameters\x12 \n\x0btemperature\x18\x01 \x01(\x02R\x0btemperature\x12\x1d\n\nmax_tokens\x18\x02 \x01(\x05R\tmaxTokens\x12\x13\n\x05top_p\x18\x03 \x01(\x02R\x04topP\x12\x13\n\x05top_k\x18\x04 \x01(\x02R\x04topK\x12+\n\x11\x66requency_penalty\x18\x05 \x01(\x02R\x10\x66requencyPenalty\x12)\n\x10presence_penalty\x18\x06 \x01(\x02R\x0fpresencePenalty\x12%\n\x0estop_sequences\x18\x07 \x03(\tR\rstopSequences\x12\x34\n\x16system_prompt_template\x18\x08 \x01(\tR\x14systemPromptTemplate\"\x9e\x01\n\x0fRateLimitConfig\x12.\n\x13requests_per_minute\x18\x01 \x01(\x05R\x11requestsPerMinute\x12*\n\x11tokens_per_minute\x18\x02 \x01(\x05R\x0ftokensPerMinute\x12/\n\x13\x63oncurrent_requests\x18\x03 \x01(\x05R\x12\x63oncurrentRequests*\xa7\x02\n\x0bLLMProvider\x12\x1c\n\x18LLM_PROVIDER_UNSPECIFIED\x10\x00\x12\x17\n\x13LLM_PROVIDER_OPENAI\x10\x01\x12\x1a\n\x16LLM_PROVIDER_ANTHROPIC\x10\x02\x12\x17\n\x13LLM_PROVIDER_COHERE\x10\x03\x12\x1d\n\x19LLM_PROVIDER_HUGGING_FACE\x10\x04\x12\x17\n\x13LLM_PROVIDER_GOOGLE\x10\x05\x12\x18\n\x14LLM_PROVIDER_MISTRAL\x10\x06\x12\x1d\n\x19LLM_PROVIDER_LOCAL_OLLAMA\x10\x07\x12\x1d\n\x19LLM_PROVIDER_AZURE_OPENAI\x10\x08\x12\x1c\n\x18LLM_PROVIDER_AWS_BEDROCK\x10\tB\x80\x02\n\x1c\x63om.nodus.v1.integrations.v1B\x08LlmProtoP\x01ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\xa2\x02\x03NVI\xaa\x02\x18Nodus.V1.Integrations.V1\xca\x02\x18Nodus\\V1\\Integrations\\V1\xe2\x02$Nodus\\V1\\Integrations\\V1\\GPBMetadata\xea\x02\x1bNodus::V1::Integrations::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.integrations.v1.llm_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.nodus.v1.integrations.v1B\010LlmProtoP\001ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\242\002\003NVI\252\002\030Nodus.V1.Integrations.V1\312\002\030Nodus\\V1\\Integrations\\V1\342\002$Nodus\\V1\\Integrations\\V1\\GPBMetadata\352\002\033Nodus::V1::Integrations::V1'
  _globals['_LLMCONFIGURATION_HEADERSENTRY']._loaded_options = None
  _globals['_LLMCONFIGURATION_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_LLMCONFIGURATION_PROVIDERSPECIFICENTRY']._loaded_options = None
  _globals['_LLMCONFIGURATION_PROVIDERSPECIFICENTRY']._serialized_options = b'8\001'
  _globals['_LLMPROVIDER']._serialized_start=1168
  _globals['_LLMPROVIDER']._serialized_end=1463
  _globals['_LLMCONFIGURATION']._serialized_start=95
  _globals['_LLMCONFIGURATION']._serialized_end=698
  _globals['_LLMCONFIGURATION_HEADERSENTRY']._serialized_start=547
  _globals['_LLMCONFIGURATION_HEADERSENTRY']._serialized_end=605
  _globals['_LLMCONFIGURATION_PROVIDERSPECIFICENTRY']._serialized_start=607
  _globals['_LLMCONFIGURATION_PROVIDERSPECIFICENTRY']._serialized_end=698
  _globals['_LLMPARAMETERS']._serialized_start=701
  _globals['_LLMPARAMETERS']._serialized_end=1004
  _globals['_RATELIMITCONFIG']._serialized_start=1007
  _globals['_RATELIMITCONFIG']._serialized_end=1165
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: vector_db/v2/vector_db.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'vector_db/v2/vector_db.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spounge.common.v2 import common_pb2 as common_dot_v2_dot_common__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cvector_db/v2/vector_db.proto\x12\x0cvector_db.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1cgoogle/protobuf/struct.proto\"e\n\x06Vector\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x16\n\x06values\x18\x02 \x03(\x02R\x06values\x12\x33\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata\"h\n\x0bQueryResult\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05score\x18\x02 \x01(\x02R\x05score\x12\x33\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata\"h\n\rUpsertRequest\x12\'\n\x0f\x63ollection_name\x18\x01 \x01(\tR\x0e\x63ollectionName\x12.\n\x07vectors\x18\x02 \x03(\x0b\x32\x14.vector_db.v2.VectorR\x07vectors\"b\n\x0eUpsertResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12%\n\x0eupserted_count\x18\x02 \x01(\x05R\rupsertedCount\"\xb0\x01\n\x0cQueryRequest\x12\'\n\x0f\x63ollection_name\x18\x01 \x01(\tR\x0e\x63ollectionName\x12!\n\x0cquery_vector\x18\x02 \x03(\x02R\x0bqueryVector\x12\x13\n\x05top_k\x18\x03 \x01(\x05R\x04topK\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructH\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"o\n\rQueryResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12\x33\n\x07results\x18\x02 \x03(\x0b\x32\x19.vector_db.v2.QueryResultR\x07results2\x9c\x01\n\x0fVectorDBService\x12\x45\n\x06Upsert\x12\x1b.vector_db.v2.UpsertRequest\x1a\x1c.vector_db.v2.UpsertResponse\"\x00\x12\x42\n\x05Query\x12\x1a.vector_db.v2.QueryRequest\x1a\x1b.vector_db.v2.QueryResponse\"\x00\x42\xb3\x01\n\x10\x63om.vector_db.v2B\rVectorDbProtoP\x01ZCgithub.com/spounge-ai/spounge-protos/gen/go/vector_db/v2;vectordbv2\xa2\x02\x03VXX\xaa\x02\x0bVectorDb.V2\xca\x02\x0bVectorDb\\V2\xe2\x02\x17VectorDb\\V2\\GPBMetadata\xea\x02\x0cVectorDb::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vector_db.v2.vector_db_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.vector_db.v2B\rVectorDbProtoP\001ZCgithub.com/spounge-ai/spounge-protos/gen/go/vector_db/v2;vectordbv2\242\002\003VXX\252\002\013VectorDb.V2\312\002\013VectorDb\\V2\342\002\027VectorDb\\V2\\GPBMetadata\352\002\014VectorDb::V2'
  _globals['_VECTOR']._serialized_start=100
  _globals['_VECTOR']._serialized_end=201
  _globals['_QUERYRESULT']._serialized_start=203
  _globals['_QUERYRESULT']._serialized_end=307
  _globals['_UPSERTREQUEST']._serialized_start=309
  _globals['_UPSERTREQUEST']._serialized_end=413
  _globals['_UPSERTRESPONSE']._serialized_start=415
  _globals['_UPSERTRESPONSE']._serialized_end=513
  _globals['_QUERYREQUEST']._serialized_start=516
  _globals['_QUERYREQUEST']._serialized_end=692
  _globals['_QUERYRESPONSE']._serialized_start=694
  _globals['_QUERYRESPONSE']._serialized_end=805
  _globals['_VECTORDBSERVICE']._serialized_start=808
  _globals['_VECTORDBSERVICE']._serialized_end=964
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/rpc/error_details.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/rpc/error_details.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egoogle/rpc/error_details.proto\x12\ngoogle.rpc\x1a\x1egoogle/protobuf/duration.proto\"\xb9\x01\n\tErrorInfo\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12?\n\x08metadata\x18\x03 \x03(\x0b\x32#.google.rpc.ErrorInfo.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"G\n\tRetryInfo\x12:\n\x0bretry_delay\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\nretryDelay\"H\n\tDebugInfo\x12#\n\rstack_entries\x18\x01 \x03(\tR\x0cstackEntries\x12\x16\n\x06\x64\x65tail\x18\x02 \x01(\tR\x06\x64\x65tail\"\x8e\x04\n\x0cQuotaFailure\x12\x42\n\nviolations\x18\x01 \x03(\x0b\x32\".google.rpc.QuotaFailure.ViolationR\nviolations\x1a\xb9\x03\n\tViolation\x12\x18\n\x07subject\x18\x01 \x01(\tR\x07subject\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x1f\n\x0b\x61pi_service\x18\x03 \x01(\tR\napiService\x12!\n\x0cquota_metric\x18\x04 \x01(\tR\x0bquotaMetric\x12\x19\n\x08quota_id\x18\x05 \x01(\tR\x07quotaId\x12\x62\n\x10quota_dimensions\x18\x06 \x03(\x0b\x32\x37.google.rpc.QuotaFailure.Violation.QuotaDimensionsEntryR\x0fquotaDimensions\x12\x1f\n\x0bquota_value\x18\x07 \x01(\x03R\nquotaValue\x12\x31\n\x12\x66uture_quota_value\x18\x08 \x01(\x03H\x00R\x10\x66utureQuotaValue\x88\x01\x01\x1a\x42\n\x14QuotaDimensionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x15\n\x13_future_quota_value\"\xbd\x01\n\x13PreconditionFailure\x12I\n\nviolations\x18\x01 \x03(\x0b\x32).google.rpc.PreconditionFailure.ViolationR\nviolations\x1a[\n\tViolation\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x18\n\x07subject\x18\x02 \x01(\tR\x07subject\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\"\x8c\x02\n\nBadRequest\x12P\n\x10\x66ield_violations\x18\x01 \x03(\x0b\x32%.google.rpc.BadRequest.FieldViolationR\x0f\x66ieldViolations\x1a\xab\x01\n\x0e\x46ieldViolation\x12\x14\n\x05\x66ield\x18\x01 \x01(\tR\x05\x66ield\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06reason\x18\x03 \x01(\tR\x06reason\x12I\n\x11localized_message\x18\x04 \x01(\x0b\x32\x1c.google.rpc.LocalizedMessageR\x10localizedMessage\"O\n\x0bRequestInfo\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12!\n\x0cserving_data\x18\x02 \x01(\tR\x0bservingData\"\x90\x01\n\x0cResourceInfo\x12#\n\rresource_type\x18\x01 \x01(\tR\x0cresourceType\x12#\n\rresource_name\x18\x02 \x01(\tR\x0cresourceName\x12\x14\n\x05owner\x18\x03 \x01(\tR\x05owner\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\"o\n\x04Help\x12+\n\x05links\x18\x01 \x03(\x0b\x32\x15.google.rpc.Help.LinkR\x05links\x1a:\n\x04Link\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\"D\n\x10LocalizedMessage\x12\x16\n\x06locale\x18\x01 \x01(\tR\x06locale\x12\x18\n\x07message\x18\x02 \x01(\tR\x07messageB\xad\x01\n\x0e\x63om.google.rpcB\x11\x45rrorDetailsProtoP\x01Z?google.golang.org/genproto/googleapis/rpc/errdetails;errdetails\xa2\x02\x03GRX\xaa\x02\nGoogle.Rpc\xca\x02\nGoogle\\Rpc\xe2\x02\x16Google\\Rpc\\GPBMetadata\xea\x02\x0bGoogle::Rpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.rpc.error_details_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.rpcB\021ErrorDetailsProtoP\001Z?google.golang.org/genproto/googleapis/rpc/errdetails;errdetails\242\002\003GRX\252\002\nGoogle.Rpc\312\002\nGoogle\\Rpc\342\002\026Google\\Rpc\\GPBMetadata\352\002\013Google::Rpc'
  _globals['_ERRORINFO_METADATAENTRY']._loaded_options = None
  _globals['_ERRORINFO_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_QUOTAFAILURE_VIOLATION_QUOTADIMENSIONSENTRY']._loaded_options = None
  _globals['_QUOTAFAILURE_VIOLATION_QUOTADIMENSIONSENTRY']._serialized_options = b'8\001'
  _globals['_ERRORINFO']._serialized_start=79
  _globals['_ERRORINFO']._serialized_end=264
  _globals['_ERRORINFO_METADATAENTRY']._serialized_start=205
  _globals['_ERRORINFO_METADATAENTRY']._serialized_end=264
  _globals['_RETRYINFO']._serialized_start=266
  _globals['_RETRYINFO']._serialized_end=337
  _globals['_DEBUGINFO']._serialized_start=339
  _globals['_DEBUGINFO']._serialized_end=411
  _globals['_QUOTAFAILURE']._serialized_start=414
  _globals['_QUOTAFAILURE']._serialized_end=940
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_start=499
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_end=940
  _globals['_QUOTAFAILURE_VIOLATION_QUOTADIMENSIONSENTRY']._serialized_start=851
  _globals['_QUOTAFAILURE_VIOLATION_QUOTADIMENSIONSENTRY']._serialized_end=917
  _globals['_PRECONDITIONFAILURE']._serialized_start=943
  _globals['_PRECONDITIONFAILURE']._serialized_end=1132
  _globals['_PRECONDITIONFAILURE_VIOLATION']._serialized_start=1041
  _globals['_PRECONDITIONFAILURE_VIOLATION']._serialized_end=1132
  _globals['_BADREQUEST']._serialized_start=1135
  _globals['_BADREQUEST']._serialized_end=1403
  _globals['_BADREQUEST_FIELDVIOLATION']._serialized_start=1232
  _globals['_BADREQUEST_FIELDVIOLATION']._serialized_end=1403
  _globals['_REQUESTINFO']._serialized_start=1405
  _globals['_REQUESTINFO']._serialized_end=1484
  _globals['_RESOURCEINFO']._serialized_start=1487
  _globals['_RESOURCEINFO']._serialized_end=1631
  _globals['_HELP']._serialized_start=1633
  _globals['_HELP']._serialized_end=1744
  _globals['_HELP_LINK']._serialized_start=1686
  _globals['_HELP_LINK']._serialized_end=1744
  _globals['_LOCALIZEDMESSAGE']._serialized_start=1746
  _globals['_LOCALIZEDMESSAGE']._serialized_end=1814
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/nodes/v1/webhook.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/nodes/v1/webhook.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fnodus/v1/nodes/v1/webhook.proto\x12\x11nodus.v1.nodes.v1\x1a\x1egoogle/protobuf/duration.proto\"\x9f\x01\n\x11WebhookNodeConfig\x12\x1b\n\tlisten_id\x18\x01 \x01(\tR\x08listenId\x12\x33\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x12\x38\n\x18verification_config_name\x18\x03 \x01(\tR\x16verificationConfigNameB\xd3\x01\n\x15\x63om.nodus.v1.nodes.v1B\x0cWebhookProtoP\x01ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\xa2\x02\x03NVN\xaa\x02\x11Nodus.V1.Nodes.V1\xca\x02\x11Nodus\\V1\\Nodes\\V1\xe2\x02\x1dNodus\\V1\\Nodes\\V1\\GPBMetadata\xea\x02\x14Nodus::V1::Nodes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.nodes.v1.webhook_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.nodus.v1.nodes.v1B\014WebhookProtoP\001ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\242\002\003NVN\252\002\021Nodus.V1.Nodes.V1\312\002\021Nodus\\V1\\Nodes\\V1\342\002\035Nodus\\V1\\Nodes\\V1\\GPBMetadata\352\002\024Nodus::V1::Nodes::V1'
  _globals['_WEBHOOKNODECONFIG']._serialized_start=87
  _globals['_WEBHOOKNODECONFIG']._serialized_end=246
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/common/v1/errors.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/common/v1/errors.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fnodus/v1/common/v1/errors.proto\x12\x12nodus.v1.common.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf8\x02\n\x0e\x45xecutionError\x12<\n\nerror_type\x18\x01 \x01(\x0e\x32\x1d.nodus.v1.common.v1.ErrorTypeR\terrorType\x12\x1d\n\nerror_code\x18\x02 \x01(\tR\terrorCode\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\x12\x1f\n\x0bstack_trace\x18\x04 \x01(\tR\nstackTrace\x12:\n\x07\x63ontext\x18\x05 \x01(\x0b\x32 .nodus.v1.common.v1.ErrorContextR\x07\x63ontext\x12\x39\n\x07\x64\x65tails\x18\x06 \x03(\x0b\x32\x1f.nodus.v1.common.v1.ErrorDetailR\x07\x64\x65tails\x12\x1c\n\tretryable\x18\x07 \x01(\x08R\tretryable\x12.\n\x13retry_after_seconds\x18\x08 \x01(\x05R\x11retryAfterSeconds\"\xb0\x02\n\x0c\x45rrorContext\x12\x1c\n\tcomponent\x18\x01 \x01(\tR\tcomponent\x12\x1c\n\toperation\x18\x02 \x01(\tR\toperation\x12P\n\nparameters\x18\x03 \x03(\x0b\x32\x30.nodus.v1.common.v1.ErrorContext.ParametersEntryR\nparameters\x12\x38\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x19\n\x08trace_id\x18\x05 \x01(\tR\x07traceId\x1a=\n\x0fParametersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x8d\x01\n\x0b\x45rrorDetail\x12\x14\n\x05\x66ield\x18\x01 \x01(\tR\x05\x66ield\x12\x1e\n\nconstraint\x18\x02 \x01(\tR\nconstraint\x12!\n\x0c\x61\x63tual_value\x18\x03 \x01(\tR\x0b\x61\x63tualValue\x12%\n\x0e\x65xpected_value\x18\x04 \x01(\tR\rexpectedValue*\xc8\x02\n\tErrorType\x12\x1a\n\x16\x45RROR_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x45RROR_TYPE_VALIDATION\x10\x01\x12\x16\n\x12\x45RROR_TYPE_TIMEOUT\x10\x02\x12\"\n\x1e\x45RROR_TYPE_RESOURCE_EXHAUSTION\x10\x03\x12\x1f\n\x1b\x45RROR_TYPE_EXTERNAL_SERVICE\x10\x04\x12\x1b\n\x17\x45RROR_TYPE_LLM_PROVIDER\x10\x05\x12\x19\n\x15\x45RROR_TYPE_MCP_SERVER\x10\x06\x12\x17\n\x13\x45RROR_TYPE_DATABASE\x10\x07\x12\x1e\n\x1a\x45RROR_TYPE_API_INTEGRATION\x10\x08\x12\x1d\n\x19\x45RROR_TYPE_AUTHENTICATION\x10\t\x12\x17\n\x13\x45RROR_TYPE_INTERNAL\x10\nB\xd9\x01\n\x16\x63om.nodus.v1.common.v1B\x0b\x45rrorsProtoP\x01ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\xa2\x02\x03NVC\xaa\x02\x12Nodus.V1.Common.V1\xca\x02\x12Nodus\\V1\\Common\\V1\xe2\x02\x1eNodus\\V1\\Common\\V1\\GPBMetadata\xea\x02\x15Nodus::V1::Common::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.common.v1.errors_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.nodus.v1.common.v1B\013ErrorsProtoP\001ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\242\002\003NVC\252\002\022Nodus.V1.Common.V1\312\002\022Nodus\\V1\\Common\\V1\342\002\036Nodus\\V1\\Common\\V1\\GPBMetadata\352\002\025Nodus::V1::Common::V1'
  _globals['_ERRORCONTEXT_PARAMETERSENTRY']._loaded_options = None
  _globals['_ERRORCONTEXT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_ERRORTYPE']._serialized_start=919
  _globals['_ERRORTYPE']._serialized_end=1247
  _globals['_EXECUTIONERROR']._serialized_start=89
  _globals['_EXECUTIONERROR']._serialized_end=465
  _globals['_ERRORCONTEXT']._serialized_start=468
  _globals['_ERRORCONTEXT']._serialized_end=772
  _globals['_ERRORCONTEXT_PARAMETERSENTRY']._serialized_start=711
  _globals['_ERRORCONTEXT_PARAMETERSENTRY']._serialized_end=772
  _globals['_ERRORDETAIL']._serialized_start=775
  _globals['_ERRORDETAIL']._serialized_end=916
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: workflow/v2/workflow.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'workflow/v2/workflow.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aworkflow/v2/workflow.proto\x12\x0bworkflow.v2\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc5\x02\n\x0eWorkflowConfig\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x18\n\x07version\x18\x05 \x01(\x05R\x07version\x12/\n\x05steps\x18\x06 \x03(\x0b\x32\x19.workflow.v2.WorkflowStepR\x05steps\x12\x39\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAtB\x0e\n\x0c_description\"\x8e\x02\n\x0cWorkflowStep\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x1b\n\ttool_name\x18\x04 \x01(\tR\x08toolName\x12\x37\n\nparameters\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructR\nparameters\x12\x1d\n\ndepends_on\x18\x06 \x03(\tR\tdependsOn\x12 \n\tsecret_id\x18\x07 \x01(\tH\x01R\x08secretId\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x0c\n\n_secret_idB\xb1\x01\n\x0f\x63om.workflow.v2B\rWorkflowProtoP\x01ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\xa2\x02\x03WXX\xaa\x02\x0bWorkflow.V2\xca\x02\x0bWorkflow\\V2\xe2\x02\x17Workflow\\V2\\GPBMetadata\xea\x02\x0cWorkflow::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workflow.v2.workflow_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.workflow.v2B\rWorkflowProtoP\001ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\242\002\003WXX\252\002\013Workflow.V2\312\002\013Workflow\\V2\342\002\027Workflow\\V2\\GPBMetadata\352\002\014Workflow::V2'
  _globals['_WORKFLOWCONFIG']._serialized_start=107
  _globals['_WORKFLOWCONFIG']._serialized_end=432
  _globals['_WORKFLOWSTEP']._serialized_start=435
  _globals['_WORKFLOWSTEP']._serialized_end=705
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/client.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/api/client.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import launch_stage_pb2 as google_dot_api_dot_launch__stage__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17google/api/client.proto\x12\ngoogle.api\x1a\x1dgoogle/api/launch_stage.proto\x1a google/protobuf/descriptor.proto\x1a\x1egoogle/protobuf/duration.proto\"\xf8\x01\n\x16\x43ommonLanguageSettings\x12\x30\n\x12reference_docs_uri\x18\x01 \x01(\tB\x02\x18\x01R\x10referenceDocsUri\x12H\n\x0c\x64\x65stinations\x18\x02 \x03(\x0e\x32$.google.api.ClientLibraryDestinationR\x0c\x64\x65stinations\x12\x62\n\x1aselective_gapic_generation\x18\x03 \x01(\x0b\x32$.google.api.SelectiveGapicGenerationR\x18selectiveGapicGeneration\"\x93\x05\n\x15\x43lientLibrarySettings\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12:\n\x0claunch_stage\x18\x02 \x01(\x0e\x32\x17.google.api.LaunchStageR\x0blaunchStage\x12,\n\x12rest_numeric_enums\x18\x03 \x01(\x08R\x10restNumericEnums\x12=\n\rjava_settings\x18\x15 \x01(\x0b\x32\x18.google.api.JavaSettingsR\x0cjavaSettings\x12:\n\x0c\x63pp_settings\x18\x16 \x01(\x0b\x32\x17.google.api.CppSettingsR\x0b\x63ppSettings\x12:\n\x0cphp_settings\x18\x17 \x01(\x0b\x32\x17.google.api.PhpSettingsR\x0bphpSettings\x12\x43\n\x0fpython_settings\x18\x18 \x01(\x0b\x32\x1a.google.api.PythonSettingsR\x0epythonSettings\x12=\n\rnode_settings\x18\x19 \x01(\x0b\x32\x18.google.api.NodeSettingsR\x0cnodeSettings\x12\x43\n\x0f\x64otnet_settings\x18\x1a \x01(\x0b\x32\x1a.google.api.DotnetSettingsR\x0e\x64otnetSettings\x12=\n\rruby_settings\x18\x1b \x01(\x0b\x32\x18.google.api.RubySettingsR\x0crubySettings\x12\x37\n\x0bgo_settings\x18\x1c \x01(\x0b\x32\x16.google.api.GoSettingsR\ngoSettings\"\xf4\x04\n\nPublishing\x12\x43\n\x0fmethod_settings\x18\x02 \x03(\x0b\x32\x1a.google.api.MethodSettingsR\x0emethodSettings\x12\"\n\rnew_issue_uri\x18\x65 \x01(\tR\x0bnewIssueUri\x12+\n\x11\x64ocumentation_uri\x18\x66 \x01(\tR\x10\x64ocumentationUri\x12$\n\x0e\x61pi_short_name\x18g \x01(\tR\x0c\x61piShortName\x12!\n\x0cgithub_label\x18h \x01(\tR\x0bgithubLabel\x12\x34\n\x16\x63odeowner_github_teams\x18i \x03(\tR\x14\x63odeownerGithubTeams\x12$\n\x0e\x64oc_tag_prefix\x18j \x01(\tR\x0c\x64ocTagPrefix\x12I\n\x0corganization\x18k \x01(\x0e\x32%.google.api.ClientLibraryOrganizationR\x0corganization\x12L\n\x10library_settings\x18m \x03(\x0b\x32!.google.api.ClientLibrarySettingsR\x0flibrarySettings\x12I\n!proto_reference_documentation_uri\x18n \x01(\tR\x1eprotoReferenceDocumentationUri\x12G\n rest_reference_documentation_uri\x18o \x01(\tR\x1drestReferenceDocumentationUri\"\x9a\x02\n\x0cJavaSettings\x12\'\n\x0flibrary_package\x18\x01 \x01(\tR\x0elibraryPackage\x12_\n\x13service_class_names\x18\x02 \x03(\x0b\x32/.google.api.JavaSettings.ServiceClassNamesEntryR\x11serviceClassNames\x12:\n\x06\x63ommon\x18\x03 \x01(\x0b\x32\".google.api.CommonLanguageSettingsR\x06\x63ommon\x1a\x44\n\x16ServiceClassNamesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"I\n\x0b\x43ppSettings\x12:\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\".google.api.CommonLanguageSettingsR\x06\x63ommon\"I\n\x0bPhpSettings\x12:\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\".google.api.CommonLanguageSettingsR\x06\x63ommon\"\x87\x03\n\x0ePythonSettings\x12:\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\".google.api.CommonLanguageSettingsR\x06\x63ommon\x12\x64\n\x15\x65xperimental_features\x18\x02 \x01(\x0b\x32/.google.api.PythonSettings.ExperimentalFeaturesR\x14\x65xperimentalFeatures\x1a\xd2\x01\n\x14\x45xperimentalFeatures\x12\x31\n\x15rest_async_io_enabled\x18\x01 \x01(\x08R\x12restAsyncIoEnabled\x12\x45\n\x1fprotobuf_pythonic_types_enabled\x18\x02 \x01(\x08R\x1cprotobufPythonicTypesEnabled\x12@\n\x1cunversioned_package_disabled\x18\x03 \x01(\x08R\x1aunversionedPackageDisabled\"J\n\x0cNodeSettings\x12:\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\".google.api.CommonLanguageSettingsR\x06\x63ommon\"\xae\x04\n\x0e\x44otnetSettings\x12:\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\".google.api.CommonLanguageSettingsR\x06\x63ommon\x12Z\n\x10renamed_services\x18\x02 \x03(\x0b\x32/.google.api.DotnetSettings.RenamedServicesEntryR\x0frenamedServices\x12]\n\x11renamed_resources\x18\x03 \x03(\x0b\x32\x30.google.api.DotnetSettings.RenamedResourcesEntryR\x10renamedResources\x12+\n\x11ignored_resources\x18\x04 \x03(\tR\x10ignoredResources\x12\x38\n\x18\x66orced_namespace_aliases\x18\x05 \x03(\tR\x16\x66orcedNamespaceAliases\x12\x35\n\x16handwritten_signatures\x18\x06 \x03(\tR\x15handwrittenSignatures\x1a\x42\n\x14RenamedServicesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x43\n\x15RenamedResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"J\n\x0cRubySettings\x12:\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\".google.api.CommonLanguageSettingsR\x06\x63ommon\"\xe4\x01\n\nGoSettings\x12:\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\".google.api.CommonLanguageSettingsR\x06\x63ommon\x12V\n\x10renamed_services\x18\x02 \x03(\x0b\x32+.google.api.GoSettings.RenamedServicesEntryR\x0frenamedServices\x1a\x42\n\x14RenamedServicesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xc2\x03\n\x0eMethodSettings\x12\x1a\n\x08selector\x18\x01 \x01(\tR\x08selector\x12I\n\x0clong_running\x18\x02 \x01(\x0b\x32&.google.api.MethodSettings.LongRunningR\x0blongRunning\x12\x32\n\x15\x61uto_populated_fields\x18\x03 \x03(\tR\x13\x61utoPopulatedFields\x1a\x94\x02\n\x0bLongRunning\x12G\n\x12initial_poll_delay\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10initialPollDelay\x12\x32\n\x15poll_delay_multiplier\x18\x02 \x01(\x02R\x13pollDelayMultiplier\x12?\n\x0emax_poll_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0cmaxPollDelay\x12G\n\x12total_poll_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10totalPollTimeout\"u\n\x18SelectiveGapicGeneration\x12\x18\n\x07methods\x18\x01 \x03(\tR\x07methods\x12?\n\x1cgenerate_omitted_as_internal\x18\x02 \x01(\x08R\x19generateOmittedAsInternal*\xa3\x01\n\x19\x43lientLibraryOrganization\x12+\n\'CLIENT_LIBRARY_ORGANIZATION_UNSPECIFIED\x10\x00\x12\t\n\x05\x43LOUD\x10\x01\x12\x07\n\x03\x41\x44S\x10\x02\x12\n\n\x06PHOTOS\x10\x03\x12\x0f\n\x0bSTREET_VIEW\x10\x04\x12\x0c\n\x08SHOPPING\x10\x05\x12\x07\n\x03GEO\x10\x06\x12\x11\n\rGENERATIVE_AI\x10\x07*g\n\x18\x43lientLibraryDestination\x12*\n&CLIENT_LIBRARY_DESTINATION_UNSPECIFIED\x10\x00\x12\n\n\x06GITHUB\x10\n\x12\x13\n\x0fPACKAGE_MANAGER\x10\x14:J\n\x10method_signature\x12\x1e.google.protobuf.MethodOptions\x18\x9b\x08 \x03(\tR\x0fmethodSignature:C\n\x0c\x64\x65\x66\x61ult_host\x12\x1f.google.protobuf.ServiceOptions\x18\x99\x08 \x01(\tR\x0b\x64\x65\x66\x61ultHost:C\n\x0coauth_scopes\x12\x1f.google.protobuf.ServiceOptions\x18\x9a\x08 \x01(\tR\x0boauthScopes:D\n\x0b\x61pi_version\x12\x1f.google.protobuf.ServiceOptions\x18\xc1\xba\xab\xfa\x01 \x01(\tR\napiVersionB\xa9\x01\n\x0e\x63om.google.apiB\x0b\x43lientProtoP\x01ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\xa2\x02\x03GAX\xaa\x02\nGoogle.Api\xca\x02\nGoogle\\Api\xe2\x02\x16Google\\Api\\GPBMetadata\xea\x02\x0bGoogle::Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.client_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.apiB\013ClientProtoP\001ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\242\002\003GAX\252\002\nGoogle.Api\312\002\nGoogle\\Api\342\002\026Google\\Api\\GPBMetadata\352\002\013Google::Api'
  _globals['_COMMONLANGUAGESETTINGS'].fields_by_name['reference_docs_uri']._loaded_options = None
  _globals['_COMMONLANGUAGESETTINGS'].fields_by_name['reference_docs_uri']._serialized_options = b'\030\001'
  _globals['_JAVASETTINGS_SERVICECLASSNAMESENTRY']._loaded_options = None
  _globals['_JAVASETTINGS_SERVICECLASSNAMESENTRY']._serialized_options = b'8\001'
  _globals['_DOTNETSETTINGS_RENAMEDSERVICESENTRY']._loaded_options = None
  _globals['_DOTNETSETTINGS_RENAMEDSERVICESENTRY']._serialized_options = b'8\001'
  _globals['_DOTNETSETTINGS_RENAMEDRESOURCESENTRY']._loaded_options = None
  _globals['_DOTNETSETTINGS_RENAMEDRESOURCESENTRY']._serialized_options = b'8\001'
  _globals['_GOSETTINGS_RENAMEDSERVICESENTRY']._loaded_options = None
  _globals['_GOSETTINGS_RENAMEDSERVICESENTRY']._serialized_options = b'8\001'
  _globals['_CLIENTLIBRARYORGANIZATION']._serialized_start=4026
  _globals['_CLIENTLIBRARYORGANIZATION']._serialized_end=4189
  _globals['_CLIENTLIBRARYDESTINATION']._serialized_start=4191
  _globals['_CLIENTLIBRARYDESTINATION']._serialized_end=4294
  _globals['_COMMONLANGUAGESETTINGS']._serialized_start=137
  _globals['_COMMONLANGUAGESETTINGS']._serialized_end=385
  _globals['_CLIENTLIBRARYSETTINGS']._serialized_start=388
  _globals['_CLIENTLIBRARYSETTINGS']._serialized_end=1047
  _globals['_PUBLISHING']._serialized_start=1050
  _globals['_PUBLISHING']._serialized_end=1678
  _globals['_JAVASETTINGS']._serialized_start=1681
  _globals['_JAVASETTINGS']._serialized_end=1963
  _globals['_JAVASETTINGS_SERVICECLASSNAMESENTRY']._serialized_start=1895
  _globals['_JAVASETTINGS_SERVICECLASSNAMESENTRY']._serialized_end=1963
  _globals['_CPPSETTINGS']._serialized_start=1965
  _globals['_CPPSETTINGS']._serialized_end=2038
  _globals['_PHPSETTINGS']._serialized_start=2040
  _globals['_PHPSETTINGS']._serialized_end=2113
  _globals['_PYTHONSETTINGS']._serialized_start=2116
  _globals['_PYTHONSETTINGS']._serialized_end=2507
  _globals['_PYTHONSETTINGS_EXPERIMENTALFEATURES']._serialized_start=2297
  _globals['_PYTHONSETTINGS_EXPERIMENTALFEATURES']._serialized_end=2507
  _globals['_NODESETTINGS']._serialized_start=2509
  _globals['_NODESETTINGS']._serialized_end=2583
  _globals['_DOTNETSETTINGS']._serialized_start=2586
  _globals['_DOTNETSETTINGS']._serialized_end=3144
  _globals['_DOTNETSETTINGS_RENAMEDSERVICESENTRY']._serialized_start=3009
  _globals['_DOTNETSETTINGS_RENAMEDSERVICESENTRY']._serialized_end=3075
  _globals['_DOTNETSETTINGS_RENAMEDRESOURCESENTRY']._serialized_start=3077
  _globals['_DOTNETSETTINGS_RENAMEDRESOURCESENTRY']._serialized_end=3144
  _globals['_RUBYSETTINGS']._serialized_start=3146
  _globals['_RUBYSETTINGS']._serialized_end=3220
  _globals['_GOSETTINGS']._serialized_start=3223
  _globals['_GOSETTINGS']._serialized_end=3451
  _globals['_GOSETTINGS_RENAMEDSERVICESENTRY']._serialized_start=3009
  _globals['_GOSETTINGS_RENAMEDSERVICESENTRY']._serialized_end=3075
  _globals['_METHODSETTINGS']._serialized_start=3454
  _globals['_METHODSETTINGS']._serialized_end=3904
  _globals['_METHODSETTINGS_LONGRUNNING']._serialized_start=3628
  _globals['_METHODSETTINGS_LONGRUNNING']._serialized_end=3904
  _globals['_SELECTIVEGAPICGENERATION']._serialized_start=3906
  _globals['_SELECTIVEGAPICGENERATION']._serialized_end=4023
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/mcp/v1/connection.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/mcp/v1/connection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from spounge.nodus.v1.mcp.v1 import server_pb2 as nodus_dot_v1_dot_mcp_dot_v1_dot_server__pb2
from spounge.nodus.v1.mcp.v1 import tool_pb2 as nodus_dot_v1_dot_mcp_dot_v1_dot_tool__pb2
from spounge.nodus.v1.common.v1 import errors_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_errors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n nodus/v1/mcp/v1/connection.proto\x12\x0fnodus.v1.mcp.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cnodus/v1/mcp/v1/server.proto\x1a\x1anodus/v1/mcp/v1/tool.proto\x1a\x1fnodus/v1/common/v1/errors.proto\"\xf9\x02\n\x18RegisterMCPServerRequest\x12\x1b\n\tserver_id\x18\x01 \x01(\tR\x08serverId\x12\x1a\n\x08\x65ndpoint\x18\x02 \x01(\tR\x08\x65ndpoint\x12?\n\x0bserver_type\x18\x03 \x01(\x0e\x32\x1e.nodus.v1.mcp.v1.MCPServerTypeR\nserverType\x12Q\n\x11\x63onnection_config\x18\x04 \x01(\x0b\x32$.nodus.v1.mcp.v1.MCPConnectionConfigR\x10\x63onnectionConfig\x12S\n\x08metadata\x18\x05 \x03(\x0b\x32\x37.nodus.v1.mcp.v1.RegisterMCPServerRequest.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x9b\x02\n\x19RegisterMCPServerResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x1b\n\tserver_id\x18\x02 \x01(\tR\x08serverId\x12J\n\x0c\x63\x61pabilities\x18\x03 \x01(\x0b\x32&.nodus.v1.mcp.v1.MCPServerCapabilitiesR\x0c\x63\x61pabilities\x12\x41\n\x0f\x61vailable_tools\x18\x04 \x03(\x0b\x32\x18.nodus.v1.mcp.v1.MCPToolR\x0e\x61vailableTools\x12\x38\n\x05\x65rror\x18\x05 \x01(\x0b\x32\".nodus.v1.common.v1.ExecutionErrorR\x05\x65rror\"\xa2\x01\n\x15ListMCPServersRequest\x12\x1d\n\nserver_ids\x18\x01 \x03(\tR\tserverIds\x12\x45\n\rstatus_filter\x18\x02 \x01(\x0e\x32 .nodus.v1.mcp.v1.MCPServerStatusR\x0cstatusFilter\x12#\n\rinclude_tools\x18\x03 \x01(\x08R\x0cincludeTools\"w\n\x16ListMCPServersResponse\x12\x38\n\x07servers\x18\x01 \x03(\x0b\x32\x1e.nodus.v1.mcp.v1.MCPServerInfoR\x07servers\x12#\n\rtotal_servers\x18\x02 \x01(\x05R\x0ctotalServers\"\xaf\x01\n\x14QueryMCPToolsRequest\x12\x1d\n\nserver_ids\x18\x01 \x03(\tR\tserverIds\x12\x33\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x1b.nodus.v1.mcp.v1.ToolFilterR\x06\x66ilter\x12\x14\n\x05limit\x18\x03 \x01(\x05R\x05limit\x12-\n\x12\x63ontinuation_token\x18\x04 \x01(\tR\x11\x63ontinuationToken\"\xa4\x01\n\x15QueryMCPToolsResponse\x12.\n\x05tools\x18\x01 \x03(\x0b\x32\x18.nodus.v1.mcp.v1.MCPToolR\x05tools\x12\x36\n\x17next_continuation_token\x18\x02 \x01(\tR\x15nextContinuationToken\x12#\n\rtotal_matches\x18\x03 \x01(\x05R\x0ctotalMatches\"\xb1\x01\n\nToolFilter\x12=\n\ncategories\x18\x01 \x03(\x0e\x32\x1d.nodus.v1.mcp.v1.ToolCategoryR\ncategories\x12\x12\n\x04tags\x18\x02 \x03(\tR\x04tags\x12!\n\x0cname_pattern\x18\x03 \x01(\tR\x0bnamePattern\x12-\n\x12supports_streaming\x18\x04 \x01(\x08R\x11supportsStreaming\"\xc4\x01\n\x11MCPToolInvocation\x12\x17\n\x07tool_id\x18\x01 \x01(\tR\x06toolId\x12\x1b\n\tserver_id\x18\x02 \x01(\tR\x08serverId\x12\x37\n\nparameters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\nparameters\x12@\n\x07options\x18\x04 \x01(\x0b\x32&.nodus.v1.mcp.v1.ToolInvocationOptionsR\x07options\"\xbb\x02\n\x15ToolInvocationOptions\x12/\n\x13validate_parameters\x18\x01 \x01(\x08R\x12validateParameters\x12\x31\n\x14require_confirmation\x18\x02 \x01(\x08R\x13requireConfirmation\x12\x33\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x12M\n\x07\x63ontext\x18\x04 \x03(\x0b\x32\x33.nodus.v1.mcp.v1.ToolInvocationOptions.ContextEntryR\x07\x63ontext\x1a:\n\x0c\x43ontextEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x8f\x02\n\rMCPToolResult\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x38\n\x0bresult_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\nresultData\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\x12H\n\x08metadata\x18\x04 \x03(\x0b\x32,.nodus.v1.mcp.v1.MCPToolResult.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xc8\x01\n\x13\x63om.nodus.v1.mcp.v1B\x0f\x43onnectionProtoP\x01ZAgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/mcp/v1;mcpv1\xa2\x02\x03NVM\xaa\x02\x0fNodus.V1.Mcp.V1\xca\x02\x0fNodus\\V1\\Mcp\\V1\xe2\x02\x1bNodus\\V1\\Mcp\\V1\\GPBMetadata\xea\x02\x12Nodus::V1::Mcp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.mcp.v1.connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.nodus.v1.mcp.v1B\017ConnectionProtoP\001ZAgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/mcp/v1;mcpv1\242\002\003NVM\252\002\017Nodus.V1.Mcp.V1\312\002\017Nodus\\V1\\Mcp\\V1\342\002\033Nodus\\V1\\Mcp\\V1\\GPBMetadata\352\002\022Nodus::V1::Mcp::V1'
  _globals['_REGISTERMCPSERVERREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_REGISTERMCPSERVERREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_TOOLINVOCATIONOPTIONS_CONTEXTENTRY']._loaded_options = None
  _globals['_TOOLINVOCATIONOPTIONS_CONTEXTENTRY']._serialized_options = b'8\001'
  _globals['_MCPTOOLRESULT_METADATAENTRY']._loaded_options = None
  _globals['_MCPTOOLRESULT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_REGISTERMCPSERVERREQUEST']._serialized_start=207
  _globals['_REGISTERMCPSERVERREQUEST']._serialized_end=584
  _globals['_REGISTERMCPSERVERREQUEST_METADATAENTRY']._serialized_start=525
  _globals['_REGISTERMCPSERVERREQUEST_METADATAENTRY']._serialized_end=584
  _globals['_REGISTERMCPSERVERRESPONSE']._serialized_start=587
  _globals['_REGISTERMCPSERVERRESPONSE']._serialized_end=870
  _globals['_LISTMCPSERVERSREQUEST']._serialized_start=873
  _globals['_LISTMCPSERVERSREQUEST']._serialized_end=1035
  _globals['_LISTMCPSERVERSRESPONSE']._serialized_start=1037
  _globals['_LISTMCPSERVERSRESPONSE']._serialized_end=1156
  _globals['_QUERYMCPTOOLSREQUEST']._serialized_start=1159
  _globals['_QUERYMCPTOOLSREQUEST']._serialized_end=1334
  _globals['_QUERYMCPTOOLSRESPONSE']._serialized_start=1337
  _globals['_QUERYMCPTOOLSRESPONSE']._serialized_end=1501
  _globals['_TOOLFILTER']._serialized_start=1504
  _globals['_TOOLFILTER']._serialized_end=1681
  _globals['_MCPTOOLINVOCATION']._serialized_start=1684
  _globals['_MCPTOOLINVOCATION']._serialized_end=1880
  _globals['_TOOLINVOCATIONOPTIONS']._serialized_start=1883
  _globals['_TOOLINVOCATIONOPTIONS']._serialized_end=2198
  _globals['_TOOLINVOCATIONOPTIONS_CONTEXTENTRY']._serialized_start=2140
  _globals['_TOOLINVOCATIONOPTIONS_CONTEXTENTRY']._serialized_end=2198
  _globals['_MCPTOOLRESULT']._serialized_start=2201
  _globals['_MCPTOOLRESULT']._serialized_end=2472
  _globals['_MCPTOOLRESULT_METADATAENTRY']._serialized_start=525
  _globals['_MCPTOOLRESULT_METADATAENTRY']._serialized_end=584
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/mcp/v1/tool.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/mcp/v1/tool.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spounge.nodus.v1.common.v1 import resources_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_resources__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1anodus/v1/mcp/v1/tool.proto\x12\x0fnodus.v1.mcp.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\"nodus/v1/common/v1/resources.proto\"\xe7\x03\n\x07MCPTool\x12\x17\n\x07tool_id\x18\x01 \x01(\tR\x06toolId\x12\x1b\n\tserver_id\x18\x02 \x01(\tR\x08serverId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12:\n\x0cinput_schema\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructR\x0binputSchema\x12<\n\routput_schema\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructR\x0coutputSchema\x12\x39\n\x08\x63\x61tegory\x18\x07 \x01(\x0e\x32\x1d.nodus.v1.mcp.v1.ToolCategoryR\x08\x63\x61tegory\x12\x12\n\x04tags\x18\x08 \x03(\tR\x04tags\x12]\n\x15resource_requirements\x18\t \x01(\x0b\x32(.nodus.v1.common.v1.ResourceRequirementsR\x14resourceRequirements\x12H\n\rconfiguration\x18\n \x01(\x0b\x32\".nodus.v1.mcp.v1.ToolConfigurationR\rconfiguration\"\xb5\x03\n\x11ToolConfiguration\x12\x33\n\x15requires_confirmation\x18\x01 \x01(\x08R\x14requiresConfirmation\x12-\n\x12supports_streaming\x18\x02 \x01(\x08R\x11supportsStreaming\x12\x31\n\x14required_permissions\x18\x03 \x03(\tR\x13requiredPermissions\x12h\n\x12\x64\x65\x66\x61ult_parameters\x18\x04 \x03(\x0b\x32\x39.nodus.v1.mcp.v1.ToolConfiguration.DefaultParametersEntryR\x11\x64\x65\x66\x61ultParameters\x12Y\n\x15parameter_constraints\x18\x05 \x03(\x0b\x32$.nodus.v1.mcp.v1.ParameterConstraintR\x14parameterConstraints\x1a\x44\n\x16\x44\x65\x66\x61ultParametersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xee\x01\n\x13ParameterConstraint\x12%\n\x0eparameter_name\x18\x01 \x01(\tR\rparameterName\x12H\n\x0f\x63onstraint_type\x18\x02 \x01(\x0e\x32\x1f.nodus.v1.mcp.v1.ConstraintTypeR\x0e\x63onstraintType\x12\x41\n\x10\x63onstraint_value\x18\x03 \x01(\x0b\x32\x16.google.protobuf.ValueR\x0f\x63onstraintValue\x12#\n\rerror_message\x18\x04 \x01(\tR\x0c\x65rrorMessage\"\xc5\x01\n\tToolScope\x12\x1d\n\nserver_ids\x18\x01 \x03(\tR\tserverIds\x12=\n\ncategories\x18\x02 \x03(\x0e\x32\x1d.nodus.v1.mcp.v1.ToolCategoryR\ncategories\x12\x12\n\x04tags\x18\x03 \x03(\tR\x04tags\x12\x46\n\raccess_policy\x18\x04 \x01(\x0b\x32!.nodus.v1.mcp.v1.ToolAccessPolicyR\x0c\x61\x63\x63\x65ssPolicy\"\xd6\x02\n\x10ToolAccessPolicy\x12\x31\n\x14require_confirmation\x18\x01 \x01(\x08R\x13requireConfirmation\x12\x33\n\x15restricted_operations\x18\x02 \x03(\tR\x14restrictedOperations\x12j\n\x13parameter_overrides\x18\x03 \x03(\x0b\x32\x39.nodus.v1.mcp.v1.ToolAccessPolicy.ParameterOverridesEntryR\x12parameterOverrides\x12\'\n\x0f\x61llowed_domains\x18\x04 \x03(\tR\x0e\x61llowedDomains\x1a\x45\n\x17ParameterOverridesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xc0\x02\n\x0cToolCategory\x12\x1d\n\x19TOOL_CATEGORY_UNSPECIFIED\x10\x00\x12\x1d\n\x19TOOL_CATEGORY_DATA_ACCESS\x10\x01\x12\x1d\n\x19TOOL_CATEGORY_COMPUTATION\x10\x02\x12\x1f\n\x1bTOOL_CATEGORY_COMMUNICATION\x10\x03\x12\x1d\n\x19TOOL_CATEGORY_FILE_SYSTEM\x10\x04\x12\x1d\n\x19TOOL_CATEGORY_WEB_BROWSER\x10\x05\x12\x1c\n\x18TOOL_CATEGORY_API_CLIENT\x10\x06\x12\x1a\n\x16TOOL_CATEGORY_ANALYSIS\x10\x07\x12\x1a\n\x16TOOL_CATEGORY_DATABASE\x10\x08\x12\x1e\n\x1aTOOL_CATEGORY_ML_INFERENCE\x10\t*\xe1\x01\n\x0e\x43onstraintType\x12\x1f\n\x1b\x43ONSTRAINT_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x43ONSTRAINT_TYPE_REQUIRED\x10\x01\x12\x1e\n\x1a\x43ONSTRAINT_TYPE_MIN_LENGTH\x10\x02\x12\x1e\n\x1a\x43ONSTRAINT_TYPE_MAX_LENGTH\x10\x03\x12\x1b\n\x17\x43ONSTRAINT_TYPE_PATTERN\x10\x04\x12\x18\n\x14\x43ONSTRAINT_TYPE_ENUM\x10\x05\x12\x19\n\x15\x43ONSTRAINT_TYPE_RANGE\x10\x06\x42\xc2\x01\n\x13\x63om.nodus.v1.mcp.v1B\tToolProtoP\x01ZAgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/mcp/v1;mcpv1\xa2\x02\x03NVM\xaa\x02\x0fNodus.V1.Mcp.V1\xca\x02\x0fNodus\\V1\\Mcp\\V1\xe2\x02\x1bNodus\\V1\\Mcp\\V1\\GPBMetadata\xea\x02\x12Nodus::V1::Mcp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.mcp.v1.tool_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.nodus.v1.mcp.v1B\tToolProtoP\001ZAgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/mcp/v1;mcpv1\242\002\003NVM\252\002\017Nodus.V1.Mcp.V1\312\002\017Nodus\\V1\\Mcp\\V1\342\002\033Nodus\\V1\\Mcp\\V1\\GPBMetadata\352\002\022Nodus::V1::Mcp::V1'
  _globals['_TOOLCONFIGURATION_DEFAULTPARAMETERSENTRY']._loaded_options = None
  _globals['_TOOLCONFIGURATION_DEFAULTPARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_TOOLACCESSPOLICY_PARAMETEROVERRIDESENTRY']._loaded_options = None
  _globals['_TOOLACCESSPOLICY_PARAMETEROVERRIDESENTRY']._serialized_options = b'8\001'
  _globals['_TOOLCATEGORY']._serialized_start=1830
  _globals['_TOOLCATEGORY']._serialized_end=2150
  _globals['_CONSTRAINTTYPE']._serialized_start=2153
  _globals['_CONSTRAINTTYPE']._serialized_end=2378
  _globals['_MCPTOOL']._serialized_start=114
  _globals['_MCPTOOL']._serialized_end=601
  _globals['_TOOLCONFIGURATION']._serialized_start=604
  _globals['_TOOLCONFIGURATION']._serialized_end=1041
  _globals['_TOOLCONFIGURATION_DEFAULTPARAMETERSENTRY']._serialized_start=973
  _globals['_TOOLCONFIGURATION_DEFAULTPARAMETERSENTRY']._serialized_end=1041
  _globals['_PARAMETERCONSTRAINT']._serialized_start=1044
  _globals['_PARAMETERCONSTRAINT']._serialized_end=1282
  _globals['_TOOLSCOPE']._serialized_start=1285
  _globals['_TOOLSCOPE']._serialized_end=1482
  _globals['_TOOLACCESSPOLICY']._serialized_start=1485
  _globals['_TOOLACCESSPOLICY']._serialized_end=1827
  _globals['_TOOLACCESSPOLICY_PARAMETEROVERRIDESENTRY']._serialized_start=1758
  _globals['_TOOLACCESSPOLICY_PARAMETEROVERRIDESENTRY']._serialized_end=1827
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from spounge.workflow.v2 import workflow_service_pb2 as workflow_dot_v2_dot_workflow__service__pb2


class WorkflowServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateWorkflow = channel.unary_unary(
                '/workflow.v2.WorkflowService/CreateWorkflow',
                request_serializer=workflow_dot_v2_dot_workflow__service__pb2.CreateWorkflowRequest.SerializeToString,
                response_deserializer=workflow_dot_v2_dot_workflow__service__pb2.CreateWorkflowResponse.FromString,
                _registered_method=True)
        self.GetWorkflow = channel.unary_unary(
                '/workflow.v2.WorkflowService/GetWorkflow',
                request_serializer=workflow_dot_v2_dot_workflow__service__pb2.GetWorkflowRequest.SerializeToString,
                response_deserializer=workflow_dot_v2_dot_workflow__service__pb2.GetWorkflowResponse.FromString,
                _registered_method=True)
        self.UpdateWorkflow = channel.unary_unary(
                '/workflow.v2.WorkflowService/UpdateWorkflow',
                request_serializer=workflow_dot_v2_dot_workflow__service__pb2.UpdateWorkflowRequest.SerializeToString,
                response_deserializer=workflow_dot_v2_dot_workflow__service__pb2.UpdateWorkflowResponse.FromString,
                _registered_method=True)
        self.DeleteWorkflow = channel.unary_unary(
                '/workflow.v2.WorkflowService/DeleteWorkflow',
                request_serializer=workflow_dot_v2_dot_workflow__service__pb2.DeleteWorkflowRequest.SerializeToString,
                response_deserializer=workflow_dot_v2_dot_workflow__service__pb2.DeleteWorkflowResponse.FromString,
                _registered_method=True)
        self.ListWorkflows = channel.unary_unary(
                '/workflow.v2.WorkflowService/ListWorkflows',
                request_serializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowsRequest.SerializeToString,
                response_deserializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowsResponse.FromString,
                _registered_method=True)
        self.ListWorkflowVersions = channel.unary_unary(
                '/workflow.v2.WorkflowService/ListWorkflowVersions',
                request_serializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowVersionsRequest.SerializeToString,
                response_deserializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowVersionsResponse.FromString,
                _registered_method=True)


class WorkflowServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWorkflows(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWorkflowVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkflowServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWorkflow,
                    request_deserializer=workflow_dot_v2_dot_workflow__service__pb2.CreateWorkflowRequest.FromString,
                    response_serializer=workflow_dot_v2_dot_workflow__service__pb2.CreateWorkflowResponse.SerializeToString,
            ),
            'GetWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWorkflow,
                    request_deserializer=workflow_dot_v2_dot_workflow__service__pb2.GetWorkflowRequest.FromString,
                    response_serializer=workflow_dot_v2_dot_workflow__service__pb2.GetWorkflowResponse.SerializeToString,
            ),
            'UpdateWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWorkflow,
                    request_deserializer=workflow_dot_v2_dot_workflow__service__pb2.UpdateWorkflowRequest.FromString,
                    response_serializer=workflow_dot_v2_dot_workflow__service__pb2.UpdateWorkflowResponse.SerializeToString,
            ),
            'DeleteWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteWorkflow,
                    request_deserializer=workflow_dot_v2_dot_workflow__service__pb2.DeleteWorkflowRequest.FromString,
                    response_serializer=workflow_dot_v2_dot_workflow__service__pb2.DeleteWorkflowResponse.SerializeToString,
            ),
            'ListWorkflows': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWorkflows,
                    request_deserializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowsRequest.FromString,
                    response_serializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowsResponse.SerializeToString,
            ),
            'ListWorkflowVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWorkflowVersions,
                    request_deserializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowVersionsRequest.FromString,
                    response_serializer=workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowVersionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'workflow.v2.WorkflowService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('workflow.v2.WorkflowService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class WorkflowService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/workflow.v2.WorkflowService/CreateWorkflow',
            workflow_dot_v2_dot_workflow__service__pb2.CreateWorkflowRequest.SerializeToString,
            workflow_dot_v2_dot_workflow__service__pb2.CreateWorkflowResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/workflow.v2.WorkflowService/GetWorkflow',
            workflow_dot_v2_dot_workflow__service__pb2.GetWorkflowRequest.SerializeToString,
            workflow_dot_v2_dot_workflow__service__pb2.GetWorkflowResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/workflow.v2.WorkflowService/UpdateWorkflow',
            workflow_dot_v2_dot_workflow__service__pb2.UpdateWorkflowRequest.SerializeToString,
            workflow_dot_v2_dot_workflow__service__pb2.UpdateWorkflowResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/workflow.v2.WorkflowService/DeleteWorkflow',
            workflow_dot_v2_dot_workflow__service__pb2.DeleteWorkflowRequest.SerializeToString,
            workflow_dot_v2_dot_workflow__service__pb2.DeleteWorkflowResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListWorkflows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/workflow.v2.WorkflowService/ListWorkflows',
            workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowsRequest.SerializeToString,
            workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListWorkflowVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/workflow.v2.WorkflowService/ListWorkflowVersions',
            workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowVersionsRequest.SerializeToString,
            workflow_dot_v2_dot_workflow__service__pb2.ListWorkflowVersionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: workflow/v2/execution.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'workflow/v2/execution.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spounge.common.v2 import common_pb2 as common_dot_v2_dot_common__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bworkflow/v2/execution.proto\x12\x0bworkflow.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb9\x04\n\x11WorkflowExecution\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x1f\n\x0bworkflow_id\x18\x03 \x01(\tR\nworkflowId\x12)\n\x10workflow_version\x18\x04 \x01(\x05R\x0fworkflowVersion\x12\x34\n\x06status\x18\x05 \x01(\x0e\x32\x1c.workflow.v2.ExecutionStatusR\x06status\x12\x31\n\x07\x63ontext\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructR\x07\x63ontext\x12/\n\x06output\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructR\x06output\x12,\n\x05\x65rror\x18\x08 \x01(\x0b\x32\x11.common.v2.StatusH\x00R\x05\x65rror\x88\x01\x01\x12\x39\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12>\n\nstarted_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\tstartedAt\x88\x01\x01\x12\x42\n\x0c\x63ompleted_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\x0b\x63ompletedAt\x88\x01\x01\x42\x08\n\x06_errorB\r\n\x0b_started_atB\x0f\n\r_completed_at\"\x85\x02\n\x17WorkflowExecutionUpdate\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x34\n\x06status\x18\x02 \x01(\x0e\x32\x1c.workflow.v2.ExecutionStatusR\x06status\x12<\n\rcontext_delta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x0c\x63ontextDelta\x12\x38\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x19\n\x08is_final\x18\x05 \x01(\x08R\x07isFinal*\xcc\x01\n\x0f\x45xecutionStatus\x12 \n\x1c\x45XECUTION_STATUS_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45XECUTION_STATUS_PENDING\x10\x01\x12\x1c\n\x18\x45XECUTION_STATUS_RUNNING\x10\x02\x12\x1e\n\x1a\x45XECUTION_STATUS_COMPLETED\x10\x03\x12\x1b\n\x17\x45XECUTION_STATUS_FAILED\x10\x04\x12\x1e\n\x1a\x45XECUTION_STATUS_CANCELLED\x10\x05\x42\xb2\x01\n\x0f\x63om.workflow.v2B\x0e\x45xecutionProtoP\x01ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\xa2\x02\x03WXX\xaa\x02\x0bWorkflow.V2\xca\x02\x0bWorkflow\\V2\xe2\x02\x17Workflow\\V2\\GPBMetadata\xea\x02\x0cWorkflow::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workflow.v2.execution_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.workflow.v2B\016ExecutionProtoP\001ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\242\002\003WXX\252\002\013Workflow.V2\312\002\013Workflow\\V2\342\002\027Workflow\\V2\\GPBMetadata\352\002\014Workflow::V2'
  _globals['_EXECUTIONSTATUS']._serialized_start=968
  _globals['_EXECUTIONSTATUS']._serialized_end=1172
  _globals['_WORKFLOWEXECUTION']._serialized_start=132
  _globals['_WORKFLOWEXECUTION']._serialized_end=701
  _globals['_WORKFLOWEXECUTIONUPDATE']._serialized_start=704
  _globals['_WORKFLOWEXECUTIONUPDATE']._serialized_end=965
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from spounge.llm.v2 import llm_pb2 as llm_dot_v2_dot_llm__pb2


class LLMProviderServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GenerateText = channel.unary_unary(
                '/llm.v2.LLMProviderService/GenerateText',
                request_serializer=llm_dot_v2_dot_llm__pb2.GenerateTextRequest.SerializeToString,
                response_deserializer=llm_dot_v2_dot_llm__pb2.GenerateTextResponse.FromString,
                _registered_method=True)
        self.GenerateTextStream = channel.unary_stream(
                '/llm.v2.LLMProviderService/GenerateTextStream',
                request_serializer=llm_dot_v2_dot_llm__pb2.GenerateTextStreamRequest.SerializeToString,
                response_deserializer=llm_dot_v2_dot_llm__pb2.GenerateTextStreamResponse.FromString,
                _registered_method=True)
        self.GenerateEmbedding = channel.unary_unary(
                '/llm.v2.LLMProviderService/GenerateEmbedding',
                request_serializer=llm_dot_v2_dot_llm__pb2.GenerateEmbeddingRequest.SerializeToString,
                response_deserializer=llm_dot_v2_dot_llm__pb2.GenerateEmbeddingResponse.FromString,
                _registered_method=True)


class LLMProviderServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GenerateText(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateTextStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateEmbedding(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LLMProviderServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GenerateText': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateText,
                    request_deserializer=llm_dot_v2_dot_llm__pb2.GenerateTextRequest.FromString,
                    response_serializer=llm_dot_v2_dot_llm__pb2.GenerateTextResponse.SerializeToString,
            ),
            'GenerateTextStream': grpc.unary_stream_rpc_method_handler(
                    servicer.GenerateTextStream,
                    request_deserializer=llm_dot_v2_dot_llm__pb2.GenerateTextStreamRequest.FromString,
                    response_serializer=llm_dot_v2_dot_llm__pb2.GenerateTextStreamResponse.SerializeToString,
            ),
            'GenerateEmbedding': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateEmbedding,
                    request_deserializer=llm_dot_v2_dot_llm__pb2.GenerateEmbeddingRequest.FromString,
                    response_serializer=llm_dot_v2_dot_llm__pb2.GenerateEmbeddingResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'llm.v2.LLMProviderService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('llm.v2.LLMProviderService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class LLMProviderService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GenerateText(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/llm.v2.LLMProviderService/GenerateText',
            llm_dot_v2_dot_llm__pb2.GenerateTextRequest.SerializeToString,
            llm_dot_v2_dot_llm__pb2.GenerateTextResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GenerateTextStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/llm.v2.LLMProviderService/GenerateTextStream',
            llm_dot_v2_dot_llm__pb2.GenerateTextStreamRequest.SerializeToString,
            llm_dot_v2_dot_llm__pb2.GenerateTextStreamResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GenerateEmbedding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/llm.v2.LLMProviderService/GenerateEmbedding',
            llm_dot_v2_dot_llm__pb2.GenerateEmbeddingRequest.SerializeToString,
            llm_dot_v2_dot_llm__pb2.GenerateEmbeddingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v2/dashboard_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'api/v2/dashboard_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spounge.iam.v2 import api_key_pb2 as iam_dot_v2_dot_api__key__pb2
from spounge.iam.v2 import managed_secret_pb2 as iam_dot_v2_dot_managed__secret__pb2
from spounge.user.v2 import user_pb2 as user_dot_v2_dot_user__pb2
from spounge.workflow.v2 import execution_pb2 as workflow_dot_v2_dot_execution__pb2
from spounge.workflow.v2 import workflow_pb2 as workflow_dot_v2_dot_workflow__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61pi/v2/dashboard_service.proto\x12\x06\x61pi.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x14iam/v2/api_key.proto\x1a\x1biam/v2/managed_secret.proto\x1a\x12user/v2/user.proto\x1a\x1bworkflow/v2/execution.proto\x1a\x1aworkflow/v2/workflow.proto\"\x15\n\x13GetDashboardRequest\"\xcf\x02\n\x14GetDashboardResponse\x12\x37\n\x0cuser_profile\x18\x01 \x01(\x0b\x32\x14.user.v2.UserProfileR\x0buserProfile\x12\x46\n\x10recent_workflows\x18\x02 \x03(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x0frecentWorkflows\x12K\n\x11recent_executions\x18\x03 \x03(\x0b\x32\x1e.workflow.v2.WorkflowExecutionR\x10recentExecutions\x12)\n\x08\x61pi_keys\x18\x04 \x03(\x0b\x32\x0e.iam.v2.APIKeyR\x07\x61piKeys\x12>\n\x0fmanaged_secrets\x18\x05 \x03(\x0b\x32\x15.iam.v2.ManagedSecretR\x0emanagedSecrets2t\n\x10\x44\x61shboardService\x12`\n\x0cGetDashboard\x12\x1b.api.v2.GetDashboardRequest\x1a\x1c.api.v2.GetDashboardResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v2/dashboardB\x96\x01\n\ncom.api.v2B\x15\x44\x61shboardServiceProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V2\xca\x02\x06\x41pi\\V2\xe2\x02\x12\x41pi\\V2\\GPBMetadata\xea\x02\x07\x41pi::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api.v2.dashboard_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.api.v2B\025DashboardServiceProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\242\002\003AXX\252\002\006Api.V2\312\002\006Api\\V2\342\002\022Api\\V2\\GPBMetadata\352\002\007Api::V2'
  _globals['_DASHBOARDSERVICE'].methods_by_name['GetDashboard']._loaded_options = None
  _globals['_DASHBOARDSERVICE'].methods_by_name['GetDashboard']._serialized_options = b'\202\323\344\223\002\017\022\r/v2/dashboard'
  _globals['_GETDASHBOARDREQUEST']._serialized_start=200
  _globals['_GETDASHBOARDREQUEST']._serialized_end=221
  _globals['_GETDASHBOARDRESPONSE']._serialized_start=224
  _globals['_GETDASHBOARDRESPONSE']._serialized_end=559
  _globals['_DASHBOARDSERVICE']._serialized_start=561
  _globals['_DASHBOARDSERVICE']._serialized_end=677
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: auth/v2/token.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'auth/v2/token.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61uth/v2/token.proto\x12\x07\x61uth.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe0\x01\n\tAuthToken\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12#\n\rrefresh_token\x18\x02 \x01(\tR\x0crefreshToken\x12\x39\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12\x31\n\ntoken_type\x18\x04 \x01(\x0e\x32\x12.auth.v2.TokenTypeR\ttokenType\x12\x1d\n\nsession_id\x18\x05 \x01(\tR\tsessionId*>\n\tTokenType\x12\x1a\n\x16TOKEN_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11TOKEN_TYPE_BEARER\x10\x01\x42\x92\x01\n\x0b\x63om.auth.v2B\nTokenProtoP\x01Z:github.com/spounge-ai/spounge-protos/gen/go/auth/v2;authv2\xa2\x02\x03\x41XX\xaa\x02\x07\x41uth.V2\xca\x02\x07\x41uth\\V2\xe2\x02\x13\x41uth\\V2\\GPBMetadata\xea\x02\x08\x41uth::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth.v2.token_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013com.auth.v2B\nTokenProtoP\001Z:github.com/spounge-ai/spounge-protos/gen/go/auth/v2;authv2\242\002\003AXX\252\002\007Auth.V2\312\002\007Auth\\V2\342\002\023Auth\\V2\\GPBMetadata\352\002\010Auth::V2'
  _globals['_TOKENTYPE']._serialized_start=292
  _globals['_TOKENTYPE']._serialized_end=354
  _globals['_AUTHTOKEN']._serialized_start=66
  _globals['_AUTHTOKEN']._serialized_end=290
# @@protoc_insertion_point(module_scope)



# Auto-generated __init__.py
from . import api
from . import auth
from . import common
from . import google
from . import iam
from . import llm
from . import nodus
from . import polykey
from . import user
from . import vector_db
from . import workflow

__all__ = ["api", "auth", "common", "google", "iam", "llm", "nodus", "polykey", "user", "vector_db", "workflow"]
